isSchedulingExactAlarmsPermitted property
Whether scheduling exact alarms is permitted. This is normally permitted, unless the user has manually revoked the permission from the device settings. When the permission is not granted, it can have a negative impact on the detection quality.
Implementation
final bool isSchedulingExactAlarmsPermitted;