isLocationAvailable property

bool isLocationAvailable
final

The SDK's location availability state.

Generally, when the device location setting is in an acceptable state, and all required location related permissions are granted, this property will be true. However, under certain conditions, location data may still be unavailable, in which case this property will be false. Once location data becomes available again, the SDK will automatically update this property and resume detections if possible.

Note that it can take up to 30 seconds for a change in the device's location settings or permissions to take effect on SDK's location availability state.

Implementation

final bool isLocationAvailable;