isSpeedLimitInfoSet property
true if this waypoint has a speed limit, false otherwise.
If this value is false, then speedLimitInMps will be null.
Implementation
final bool isSpeedLimitInfoSet;
true if this waypoint has a speed limit, false otherwise.
If this value is false, then speedLimitInMps will be null.
final bool isSpeedLimitInfoSet;