timestamp property

int timestamp
final

the Unix epoch time of this location fix, in milliseconds since the start of the Unix epoch (00:00:00 January 1, 1970 UTC).

Implementation

final int timestamp;