Enables SDK detections. Requires a Sentiance user to be present on the device. Enabling detections is persistent
across app restarts. Therefore, you do not need to call this method on every app startup. Once detections are
enabled, as long as the SDK is properly initialized during startup, detections will be resumed, until you
disable them by calling [disableDetections].
Enables SDK detections. Requires a Sentiance user to be present on the device. Enabling detections is persistent
across app restarts. Therefore, you do not need to call this method on every app startup. Once detections are
enabled, as long as the SDK is properly initialized during startup, detections will be resumed, until you
disable them by calling [disableDetections], or they expire (see [expiryEpochTimeMs]).
Returns the status of the SDK. You can use this information to identify possible causes for non-existing or low quality detections.
The returned object's runtime type is AndroidSdkStatus if invoked on Android, or IosSdkStatus if invoked on iOS.
Returns the tags that are currently set for the Sentiance user, as previously
provided to setUserTags. Returns an empty map if no user tags have been set.