Waypoint class
Represents a geographic location.
Constructors
Properties
- accuracy → double
-
The estimated horizontal accuracy radius in meters of this location at the 68th percentile confidence level.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isSpeedLimitInfoSet → bool
-
trueif this waypoint has a speed limit,falseotherwise.final - isSpeedLimitUnlimited → bool
-
trueif this waypoint has an unlimited speed limit,falseotherwise.final - isSynthetic → bool
-
trueif this waypoint was interpolated,falseotherwise.final - latitude → double
-
The latitude in degrees.
final
- longitude → double
-
The longitude in degrees.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- speedInMps → double?
-
The speed at the time of the location of this waypoint, in meters per second.
final
- speedLimitInMps → double?
-
The speed limit at the location of this waypoint, in meters per second.
final
- timestamp → int
-
the Unix epoch time of this location fix, in milliseconds since the start of the Unix
epoch (00:00:00 January 1, 1970 UTC).
final
Methods
-
describeProps(
) → Map< String, Object?> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override